@@ -31,7 +31,7 @@ renv_bioconductor_init_biocinstaller <- function() {
 
 }
 
-renv_bioconductor_version <- function(project) {
+renv_bioconductor_version <- function(project, refresh = FALSE) {
 
   # check and see if we have an override via option
   version <- getOption("renv.bioconductor.version")
@@ -40,9 +40,11 @@ renv_bioconductor_version <- function(project) {
 
   # check and see if the project has been configured to use a specific
   # Bioconductor release
-  version <- settings$bioconductor.version(project = project)
-  if (length(version))
-    return(version)
+  if (!refresh) {
+    version <- settings$bioconductor.version(project = project)
+    if (length(version))
+      return(version)
+  }
 
   # otherwise, infer the Bioconductor version from installed packages
   case(
@@ -84,10 +86,18 @@ renv_bioconductor_repos <- function(project, version = NULL) {
 }
 
 renv_bioconductor_repos_biocmanager <- function(version) {
+
   renv_scope_options(BiocManager.check_repositories = FALSE)
   BiocManager <- asNamespace("BiocManager")
   version <- version %||% BiocManager$version()
-  BiocManager$repositories(version = version)
+
+  tryCatch(
+    BiocManager$.repositories(site_repository = character(), version = version),
+    error = function(e) {
+      BiocManager$repositories(version = version)
+    }
+  )
+
 }
 
 renv_bioconductor_repos_biocinstaller <- function(version) {
