@@ -4,12 +4,10 @@ renv_pak_init <- function(library, type, rebuild, project) {
   if (requireNamespace("pak", quietly = TRUE))
     return(renv_namespace_load("pak"))
 
-  install(
-    packages = "pak",
-    library  = library,
-    type     = type,
-    project  = project
-  )
+  # prefer using prebuilt binaries
+  fmt <- "https://r-lib.github.io/p/pak/stable/%s/%s/%s"
+  repos <- sprintf(fmt, .Platform$pkgType, version$os, version$arch)
+  utils::install.packages("pak", repos = repos)
 
 }
 
@@ -17,7 +15,7 @@ renv_pak_install <- function(packages, library) {
 
   pak <- renv_namespace_load("pak")
   pak$pkg_install(
-    pkg     = unlist(packages, use.names = FALSE),
+    pkg     = packages,
     lib     = library[[1L]],
     upgrade = TRUE
   )
